--
-- FS22 - FieldCalculator
--
-- @Interface: 1.2.0.0 b14651
-- @Author: KR-Softwares
-- @Date: 23.01.2022
-- @Version: 1.0.0.0
--
-- @Support: kr-softwares.com
--
-- Changelog:
-- 	v1.0.0.0 (23.01.2022):
--      - Convert from from FS19 to FS22
--

FieldCalculator = {}
FieldCalculator.dir = g_currentModDirectory
FieldCalculator.modName = g_currentModName

source(FieldCalculator.dir .. "KrSoftwareUtils.lua")
source(FieldCalculator.dir .. "gui/InGameMenuFieldCalculator.lua")
source(FieldCalculator.dir .. "gui/SeedFrame.lua")

function FieldCalculator:loadMap()
	KrSoftwareUtils.loadTextFromMod(FieldCalculator.modName, FieldCalculator.dir)
	KrSoftwareUtils.mergeModTranslations(g_i18n)

	local ui = g_currentMission.inGameMenu

    g_gui:loadProfiles(FieldCalculator.dir .. "gui/guiProfiles.xml")


	local guiFieldCalculator = InGameMenuFieldCalculator.new(g_i18n) 
	g_gui:loadGui(FieldCalculator.dir .. "gui/InGameMenuFieldCalculator.xml", "ingameMenuFieldCalculator", guiFieldCalculator, true)
	
	local seedFrame = SeedFrame.new(g_i18n) 
	g_gui:loadGui(FieldCalculator.dir .. "gui/SeedFrame.xml", "SeedFrame", seedFrame)
	
	local guiElementPage = FrameReferenceElement.new(ui)
	guiElementPage.referencedFrameName = "ingameMenuFieldCalculator"
	guiElementPage.name = "ingameMenuFieldCalculator"
	guiElementPage.id = "pageFieldCalculator"

	local index, varName = GuiElement.extractIndexAndNameFromID(guiElementPage.id)	
	if index then
		if not ui[varName] then
			ui[varName] = {}
		end

		ui[varName][index] = guiElementPage
	else
		ui[varName] = guiElementPage
	end

	ui.controlIDs[varName] = true
	
	guiFieldCalculator:initialize()	

	local filename = FieldCalculator.dir .. "images/menuIcon.dds"
	ui:addPage(guiFieldCalculator, nil, filename, {0,0,1024,1024}, FieldCalculator:makeIsFieldCalculatorEnabledPredicate())
	
	ui:applyScreenAlignment()
	ui:updateAbsolutePosition()
end

function FieldCalculator:makeIsFieldCalculatorEnabledPredicate()
	return function () return true end
end

addModEventListener(FieldCalculator)


-- Now we fixe some giants bugs :)

function fixGiantsBug1(oldFunc)
	return function (s, pageFrameElement, ...)
		local pageRoot, position = oldFunc(s, pageFrameElement, ...)
		pageRoot = pageFrameElement.elements[1]
		return pageRoot, position
	end
end

function fixGiantsBug2(oldFunc)
	return function (self, pageFrameElement, position, tabIconFilename, tabIconUVs, enablingPredicateFunction)
		local pageRoot, actualPosition = self:registerPage(pageFrameElement, position, enablingPredicateFunction)

	self:addPageTab(pageFrameElement, tabIconFilename, GuiUtils.getUVs(tabIconUVs))

	local name = pageRoot.title

	if name == nil then
		name = self.l10n:getText("ui_" .. pageRoot.name)
	end

	self.pagingElement:superClass().addElement(self.pagingElement, pageFrameElement)
	self.pagingElement:addPage(string.upper(pageRoot.name), pageFrameElement, name, actualPosition)
	end
end

TabbedMenu.registerPage = fixGiantsBug1(TabbedMenu.registerPage)
TabbedMenu.addPage = fixGiantsBug2(TabbedMenu.addPage)